import datetime
from pathlib import Path

from um_ro_calendar.entities import CheckboxOption, FormFeatures, TermOption
from um_ro_calendar.fetching import FileFetcher
from um_ro_calendar.ical_feed_source import ICalEventParser, ICalFetcher

example_features = FormFeatures(
    "term_keyword",
    [TermOption("1", "Fall 2022"), TermOption("2", "Winter 2023")],
    CheckboxOption("accal", "1"),
    CheckboxOption("reg", "1"),
)


def test_ical_fetcher():
    fetcher = ICalFetcher(example_features)
    url = fetcher.get_url("Winter 2023")
    assert "calendars/feed" in url
    assert "term_keyword=2" in url


def test_successful_parse():
    data_file = Path(__file__).parent / "data" / "sample-fall2022-accal.ical"
    fetcher = FileFetcher(data_file)
    parser = ICalEventParser(fetcher)
    events = list(parser.events("Fall 2022"))
    assert len(events) == 10
    assert events[0].start_date == datetime.date(2022, 8, 29)
    assert events[0].name == "Fall 2022 classes begin"
