import datetime
from pathlib import Path

from um_ro_calendar.fetching import FileFetcher
from um_ro_calendar.html_source import HTMLEventParser
from um_ro_calendar.utils import fix_spring_break_spans


def test_fix_spring_break_spans_exist():
    html_file = Path(__file__).parent / "data" / "sample-winter2023-accalreg.html"
    parser = HTMLEventParser(FileFetcher(html_file))
    original_events = list(parser.events("Winter 2023"))
    fixed_events = list(fix_spring_break_spans(original_events))

    assert len(original_events) == 36
    assert len(fixed_events) == 35
    assert not any(e.name == "Spring Break" for e in original_events)
    assert any(e.name == "Spring Break" for e in fixed_events)

    spring_break = [e for e in fixed_events if e.name == "Spring Break"][0]
    assert spring_break.start_date == datetime.date(2023, 2, 25)
    assert spring_break.end_date == datetime.date(2023, 3, 5)


def test_fix_spring_break_spans_does_not_exist():
    html_file = Path(__file__).parent / "data" / "sample-fall2022-accal.html"
    parser = HTMLEventParser(FileFetcher(html_file))
    original_events = list(parser.events("Winter 2023"))
    fixed_events = list(fix_spring_break_spans(original_events))

    assert len(original_events) == len(fixed_events)
    assert not any(e.name == "Spring Break" for e in fixed_events)
