from pathlib import Path
from typing import Union
from urllib.request import urlopen

from .entities import FormFeatures


class BaseFetcher:
    def fetch_data(self, term_name: str) -> str:
        raise NotImplementedError


class BaseWebFetcher(BaseFetcher):
    base_url: str
    form_features: FormFeatures
    academic_calendar: bool
    registration_deadlines: bool

    def __init__(
        self,
        form_features: FormFeatures,
        academic_calendar: bool = True,
        registration_deadlines: bool = False,
    ):
        self.form_features = form_features
        self.academic_calendar = academic_calendar
        self.registration_deadlines = registration_deadlines

    def get_url(self, term_name: str):
        return self.form_features.get_url(
            term_name,
            self.base_url,
            self.academic_calendar,
            self.registration_deadlines,
        )

    def fetch_data(self, term_name: str) -> str:  # pragma: no cover
        url = self.get_url(term_name)
        return urlopen(url).read().decode("utf-8")


class FileFetcher(BaseFetcher):
    file_path: Union[str, Path]

    def __init__(self, file_path: Union[str, Path]):
        self.file_path = file_path

    def fetch_data(self, term_name: str) -> str:
        return open(self.file_path).read()
