from datetime import timedelta
from typing import Iterable

from .entities import Event


def fix_spring_break_spans(events: Iterable[Event]) -> Iterable[Event]:
    vacation_begins = None
    classes_resume = None

    for event in events:
        if event.name.startswith("Vacation begins at noon"):
            vacation_begins = event
        elif event.name.startswith("Classes resume 8"):
            classes_resume = event

        if vacation_begins:
            if classes_resume:
                yield Event(
                    "Spring Break",
                    vacation_begins.start_date,
                    classes_resume.end_date - timedelta(days=1),
                )
                vacation_begins = None
                classes_resume = None
        else:
            yield event
